from slowcessing import PJApplet, pj_frame, shoebot_imports
from processing.opengl import *

shoebot_imports()
import web
import thread

class ImageQueue(list):
    """
    Download images in the background and add them to a list
    """
    def __init__(self, search, size):
        list.__init__(self)
        self._search = search
        self._image_size = size
        thread.start_new_thread(self._get_images, ())

    def _image_downloaded(self, path):
        self.append(path)
    
    def _get_images(self):
        for image in self._search:
            image.download(self._image_size, asynchronous=False)
            self._image_downloaded(image.path)
      

class PJImageQueue(ImageQueue):
    """
    ImageQueue that uses processing to load the images as they come in, 
    """
    def __init__(self, pjapplet, search, size):
        self.pjapplet = pjapplet
        ImageQueue.__init__(self, search, size)

    def _image_downloaded(self, path):
        img = self.pjapplet.loadImage(path)
        self.append(img)

class WebTest (PJApplet):
    def _set_images(self):
        self.images = PJImageQueue(self, web.morguefile.search("rocks", max=10), size='small')

    def setup(self):
        self.size(400, 400, self.P3D)
        self._set_images()
    
    def draw(self):
        self.background(0);
        y = (self.height * 0.2 ) - self.mouseY * (len(self.images) * 0.58)
        for image in self.images:
            self.image(image, 20, y)
            y += image.height

    def keyPressed(self, key):
        self._set_images()
        if key == self.ESC:
            self.exit()

if __name__ == '__main__':
    pj_frame(WebTest, resizable = True)
